@@ -4,36 +4,14 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.03';
+use JIRA::REST::Class::Version qw( $VERSION );
 
 # ABSTRACT: A factory class for building all the other classes in C<JIRA::REST::Class>.
 
-# here is our list of every class this factory knows how to make
+# we import the list of every class this factory knows how to make
 #
-JIRA::REST::Class::Factory->add_factory_type(
-    factory      => 'JIRA::REST::Class::Factory',
-    issue        => 'JIRA::REST::Class::Issue',
-    changelog    => 'JIRA::REST::Class::Issue::Changelog',
-    change       => 'JIRA::REST::Class::Issue::Changelog::Change',
-    changeitem   => 'JIRA::REST::Class::Issue::Changelog::Change::Item',
-    linktype     => 'JIRA::REST::Class::Issue::LinkType',
-    status       => 'JIRA::REST::Class::Issue::Status',
-    statuscat    => 'JIRA::REST::Class::Issue::Status::Category',
-    timetracking => 'JIRA::REST::Class::Issue::TimeTracking',
-    transitions  => 'JIRA::REST::Class::Issue::Transitions',
-    transition   => 'JIRA::REST::Class::Issue::Transitions::Transition',
-    issuetype    => 'JIRA::REST::Class::Issue::Type',
-    worklog      => 'JIRA::REST::Class::Issue::Worklog',
-    workitem     => 'JIRA::REST::Class::Issue::Worklog::Item',
-    project      => 'JIRA::REST::Class::Project',
-    projectcat   => 'JIRA::REST::Class::Project::Category',
-    projectcomp  => 'JIRA::REST::Class::Project::Component',
-    projectvers  => 'JIRA::REST::Class::Project::Version',
-    iterator     => 'JIRA::REST::Class::Iterator',
-    sprint       => 'JIRA::REST::Class::Sprint',
-    query        => 'JIRA::REST::Class::Query',
-    user         => 'JIRA::REST::Class::User',
-);
+use JIRA::REST::Class::FactoryTypes qw( %TYPES );
+JIRA::REST::Class::Factory->add_factory_type( %TYPES );
 
 use Carp;
 use DateTime::Format::Strptime;
@@ -75,8 +53,10 @@ sub make_object {
 sub make_date {
     my ($self, $date) = @_;
     return unless $date;
-    state $parser = DateTime::Format::Strptime->new( pattern => '%FT%T.%N%Z' );
-    return $parser->parse_datetime($date);
+    my $pattern = '%FT%T.%N%z';
+    state $parser = DateTime::Format::Strptime->new( pattern => $pattern );
+    return( $parser->parse_datetime($date) or
+        confess qq{Unable to parse date "$date" using pattern "$pattern"} );
 }
 
 #pod =internal_method B<factory_error>
@@ -109,7 +89,7 @@ JIRA::REST::Class::Factory - A factory class for building all the other classes
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 INTERNAL METHODS
 
