@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.03';
+use JIRA::REST::Class::Version qw( $VERSION );
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents an individual JIRA issue as an object.
 
@@ -120,6 +120,14 @@ __PACKAGE__->mk_lazy_ro_accessor('changelog', sub {
     $self->make_object('changelog');
 });
 
+__PACKAGE__->mk_lazy_ro_accessor('comments', sub {
+    my $self = shift;
+    my $data = $self->get('/comment');
+    $self->{comments} = [ map {
+        $self->make_object('comment', { data => $_ });
+    } @{ $data->{comments} } ];
+});
+
 __PACKAGE__->mk_lazy_ro_accessor('worklog', sub {
     my $self = shift;
     $self->make_object('worklog');
@@ -701,16 +709,16 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
-isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
-maxResults originalEstimate originalEstimateSeconds parentkey projectId
-rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
-sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
-timeestimate timeoriginalestimate timespent timetracking toString
-updateAuthor worklog workratio
+isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jira jql
+lastViewed maxResults originalEstimate originalEstimateSeconds parentkey
+projectId rapidViewId remainingEstimate remainingEstimateSeconds
+resolutiondate sprintlist startDate subtaskIssueTypes timeSpent
+timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking
+toString updateAuthor worklog workratio
 
 =head1 NAME
 
@@ -718,7 +726,7 @@ JIRA::REST::Class::Issue - A helper class for C<JIRA::REST::Class> that represen
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 READ-ONLY ACCESSORS
 
