@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.03';
+use JIRA::REST::Class::Version qw( $VERSION );
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
 
@@ -117,16 +117,16 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
-isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
-maxResults originalEstimate originalEstimateSeconds parentkey projectId
-rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
-sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
-timeestimate timeoriginalestimate timespent timetracking toString
-updateAuthor worklog workratio
+isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jira jql
+lastViewed maxResults originalEstimate originalEstimateSeconds parentkey
+projectId rapidViewId remainingEstimate remainingEstimateSeconds
+resolutiondate sprintlist startDate subtaskIssueTypes timeSpent
+timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking
+toString updateAuthor worklog workratio
 
 =head1 NAME
 
@@ -134,7 +134,7 @@ JIRA::REST::Class::Issue::TimeTracking - A helper class for C<JIRA::REST::Class>
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 READ-ONLY ACCESSORS
 
