@@ -6,7 +6,7 @@ use v5.10;
 
 use Carp;
 
-our $VERSION = '0.03';
+use JIRA::REST::Class::Version qw( $VERSION );
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
@@ -15,6 +15,11 @@ __PACKAGE__->mk_contextual_ro_accessors(qw/ transitions /);
 sub init {
     my $self = shift;
     $self->SUPER::init(@_);
+    $self->_refresh_transitions;
+}
+
+sub _refresh_transitions {
+    my $self = shift;
 
     $self->{data} = $self->issue->get('/transitions?expand=transitions.fields');
 
@@ -23,7 +28,6 @@ sub init {
     } @{ $self->data->{transitions} } ];
 }
 
-
 #pod =internal_method B<find_transition_named>
 #pod
 #pod Returns the transition object for the named transition provided.
@@ -34,6 +38,8 @@ sub find_transition_named {
     my $self = shift;
     my $name = shift or confess "no name specified";
 
+    $self->_refresh_transitions;
+
     foreach my $transition ( $self->transitions ) {
         next unless $transition->name eq $name;
         return $transition;
@@ -141,10 +147,10 @@ sub transition_walk {
     my $target   = shift;
     my $map      = shift;
     my $callback = shift // sub {};
-
-    my $assignee = $self->issue->assignee;
     my $name     = $self->issue->status->name;
 
+    my $orig_assignee = $self->issue->assignee // q{};
+
     until ($name eq $target) {
         if (exists $map->{$name} ) {
             my $to = $map->{$name};
@@ -166,8 +172,9 @@ sub transition_walk {
 
     # put the owner back to who it's supposed
     # to be if it changed during our walk
-    if ($self->issue->assignee ne $assignee) {
-        $self->issue->set_assignee($assignee);
+    my $current_assignee = $self->issue->assignee // q{};
+    if ($current_assignee ne $orig_assignee) {
+        $self->issue->set_assignee($orig_assignee);
     }
 }
 
@@ -187,7 +194,7 @@ JIRA::REST::Class::Issue::Transitions - A helper class for C<JIRA::REST::Class>
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 METHODS
 
