@@ -4,41 +4,38 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.03';
+use JIRA::REST::Class::Version qw( $VERSION );
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents a JIRA project as an object.
 
-__PACKAGE__->mk_data_ro_accessors(qw( avatarUrls expand id key name projectTypeKey self ));
+__PACKAGE__->mk_data_ro_accessors(qw( avatarUrls expand id key name
+                                      projectTypeKey self ));
 
-_make_lazy_ro_accessors(qw/ category assigneeType components description
-                            issueTypes subtaskIssueTypes lead roles versions /);
-
-use overload
-    '""'   => sub { shift->key },
-    '0+'   => sub { shift->id  },
-    '<=>'  => sub {
-        my($A, $B) = @_;
-        my $AA = ref $A ? $A->id : $A;
-        my $BB = ref $B ? $B->id : $B;
-        $AA <=> $BB
-    },
-    'cmp'  => sub {
-        my($A, $B) = @_;
-        my $AA = ref $A ? $A->name : $A;
-        my $BB = ref $B ? $B->name : $B;
-        $AA cmp $BB
-    };
-
-sub _make_lazy_ro_accessors {
-    foreach my $field (@_) {
-        __PACKAGE__->mk_lazy_ro_accessor($field, sub {
-            my $self = shift;
-            $self->_do_lazy_load(@_);
-            $self->{$field};
-        }, @_);
-    }
+for my $field (qw/ category assigneeType components description
+                   issueTypes subtaskIssueTypes lead roles versions /) {
+    __PACKAGE__->mk_lazy_ro_accessor($field, sub {
+                                         my $self = shift;
+                                         $self->_do_lazy_load(@_);
+                                         $self->{$field};
+                                     });
 }
 
+#
+# I'm putting this here as a reminder to myself and as an explanation to
+# anyone who wonders why I'm lazily loading so much information. There are
+# two ways this object can be instantiated: either as a request for all the
+# information on a particular project, or as an accessor object wrapping
+# the data returned by the GET /rest/api/latest/project API call, which
+# only returns the following attributes: "self", "id", "key", "name",
+# "avatarUrls", and "projectCategory".  I didn't want to incur a REST API
+# call for each of these objects if all they were being used for is
+# accessing the data in the project list, so I made the accessors for
+# information that wasn't in that list be lazily loaded.  If the end user
+# gets an object from the project list method and asks for information that
+# only comes from making the full /rest/api/latest/project/{projectIdOrKey}
+# API call, we make the call at that time.
+#
+
 sub _do_lazy_load {
     my $self  = shift;
 
@@ -267,6 +264,25 @@ sub field_name {
     return $self->{field_names}->{$name};
 }
 
+
+
+use overload
+    '""'   => sub { shift->key },
+    '0+'   => sub { shift->id  },
+    '<=>'  => sub {
+        my($A, $B) = @_;
+        my $AA = ref $A ? $A->id : $A;
+        my $BB = ref $B ? $B->id : $B;
+        $AA <=> $BB
+    },
+    'cmp'  => sub {
+        my($A, $B) = @_;
+        my $AA = ref $A ? $A->name : $A;
+        my $BB = ref $B ? $B->name : $B;
+        $AA cmp $BB
+    };
+
+
 1;
 
 __END__
@@ -275,16 +291,16 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
-isAssigneeTypeValid issueTypes issuelinks issuetype jira jql lastViewed
-maxResults originalEstimate originalEstimateSeconds parentkey projectId
-rapidViewId remainingEstimate remainingEstimateSeconds resolutiondate
-sprintlist startDate subtaskIssueTypes timeSpent timeSpentSeconds
-timeestimate timeoriginalestimate timespent timetracking toString
-updateAuthor worklog workratio
+isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jira jql
+lastViewed maxResults originalEstimate originalEstimateSeconds parentkey
+projectId rapidViewId remainingEstimate remainingEstimateSeconds
+resolutiondate sprintlist startDate subtaskIssueTypes timeSpent
+timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking
+toString updateAuthor worklog workratio
 
 =head1 NAME
 
@@ -292,7 +308,7 @@ JIRA::REST::Class::Project - A helper class for C<JIRA::REST::Class> that repres
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 METHODS
 
